@@ -234,14 +234,14 @@ namespace Lum {
         DBusConnection* InitiateDBusConnection(DBusBusType busType);
 #endif
 
-      private:
-        void EnlargeUCS2Buffer(int len);
-
-        void SetUTF8Property(Window* window, Atom property, std::wstring value);
         void SetAtomProperty(Window* window, Atom property, Atom value);
         void SetCardinalProperty(Window* window, Atom property, int value);
+        void SetIntegerProperty(Window* window, Atom property, int value);
         void SetEmbedInfoProperty(::Window window);
 
+      private:
+        void EnlargeUCS2Buffer(int len);
+
         void SendNetSystemTrayRequestDock(::Window window);
         void SendNetSystemTrayBaloonMessage(Window* window);
 
