@@ -28,17 +28,6 @@ namespace Lum {
 
   class LUMAPI StatusLine : public List
   {
-  public:
-    class Prefs : public Object::Prefs
-    {
-    public:
-      OS::FrameRef iFrame;  // Frame around inner element
-
-    public:
-      Prefs();
-      void Initialize();
-    };
-
   private:
     size_t xRest;
     size_t yRest;
