@@ -361,7 +361,8 @@ namespace Lum {
 
     void File::SetPath(const std::wstring& path)
     {
-      if (options->existingOnly && !Base::Path::Exists(path)) {
+      if (options->existingOnly &&
+          !Base::Path::Exists(path)) {
         return;
       }
 
@@ -398,7 +399,9 @@ namespace Lum {
       }
       dirList->On();
 
-      if (dirList->GetRows()>0) {
+      // TODO: If path is not empty, try to select it in existing list.
+      if (dirList->GetRows()>0 &&
+          path->Get().IsEmpty()) {
         dynamic_cast<Model::SingleLineSelection*>(table->GetTableView()->GetSelection())->SelectLine(1);
       }
     }
