@@ -62,19 +62,18 @@ namespace Lum {
       width=extImage->GetWidth();
       height=extImage->GetHeight();
     }
-    else if (extStatefulImage.Valid()) {
+    else if (extStatefulImage.Valid() &&
+             extStatefulImage->IsValid()) {
       width=extStatefulImage->GetWidth();
       height=extStatefulImage->GetHeight();
     }
+    else if (OS::display->GetType()==OS::Display::typeTextual) {
+      width=1;
+      height=1;
+    }
     else {
-      if (OS::display->GetType()==OS::Display::typeTextual) {
-        width=1;
-        height=1;
-      }
-      else {
-        width=20;
-        height=20;
-      }
+      width=20;
+      height=20;
     }
 
     minWidth=width;
@@ -100,16 +99,21 @@ namespace Lum {
     if (osImage.Valid()) {
       OS::DrawInfo *draw=GetDrawInfo();
 
-      osImage->Draw(draw,this->x,this->y,this->width,this->height);
+      osImage->DrawStretched(draw,
+                             this->x,this->y,
+                             HorizontalFlex() ? this->width : osImage->GetWidth(),
+                             VerticalFlex() ? this->height : osImage->GetHeight());
     }
     else if (extImage.Valid()) {
       OS::DrawInfo *draw=GetDrawInfo();
-
-      extImage->DrawSub(draw,0,0,this->width,this->height,
-                     this->x+(width-extImage->GetWidth())/2,
-                     this->y+(height-extImage->GetHeight())/2);
+      extImage->DrawSub(draw,
+                        0,0,
+                        extImage->GetWidth(),extImage->GetHeight(),
+                        this->x+(width-extImage->GetWidth())/2,
+                        this->y+(height-extImage->GetHeight())/2);
     }
-    else if (extStatefulImage.Valid()) {
+    else if (extStatefulImage.Valid() &&
+             extStatefulImage->IsValid()) {
       OS::DrawInfo *draw=GetDrawInfo();
       Images::ImageRef image=extStatefulImage->GetNormalImage();
 
@@ -126,7 +130,9 @@ namespace Lum {
         image=extStatefulImage->GetActivatedImage();
       }
 
-      image->DrawSub(draw,0,0,this->width,this->height,
+      image->DrawSub(draw,
+                     0,0,
+                     image->GetWidth(),image->GetHeight(),
                      this->x+(width-image->GetWidth())/2,
                      this->y+(height-image->GetHeight())/2);
     }
