@@ -273,7 +273,7 @@ namespace Lum {
         imageWidth=(imageWidth*height)/imageHeight;
       }
 
-      if (event->x>=GetX()+GetWidth()-1-imageWidth) {
+      if (event->x>=GetX()+(int)(GetWidth()-1-imageWidth)) {
         return false;
       }
     }
@@ -1550,21 +1550,24 @@ namespace Lum {
   }
 
   String::InputHelper::InputHelper()
-   : backAction(new Model::Action())
+   : backAction(new Model::Action()),
+     string(NULL)
   {
     Observe(backAction);
   }
 
   void String::InputHelper::RegisterKey(Model::Action* action, const std::wstring& string)
   {
-    assert(action!=NULL && !string.empty());
+    assert(action!=NULL);
+    assert(!string.empty());
 
     Observe(action);
 
     strings[action]=string;
   }
 
-  Button* String::InputHelper::CreateTextButton(const std::wstring& label, const std::wstring& text)
+  Button* String::InputHelper::CreateTextButton(const std::wstring& label,
+                                                const std::wstring& text)
   {
     Button           *button;
     Model::ActionRef action=new Model::Action();
@@ -1576,7 +1579,8 @@ namespace Lum {
     return button;
   }
 
-  Button* String::InputHelper::CreateTextButton(const std::wstring& label, Model::Action* action)
+  Button* String::InputHelper::CreateTextButton(const std::wstring& label,
+                                                Model::Action* action)
   {
     return Button::Create(label,action,true,true);
   }
@@ -1590,36 +1594,32 @@ namespace Lum {
 
   void String::InputHelper::Close()
   {
-    strings.clear();
-
     Popup::Close();
   }
 
   void String::InputHelper::Resync(Base::Model* model, const Base::ResyncMsg& msg)
   {
-    if (dynamic_cast<Model::Action*>(model)!=NULL &&
-             dynamic_cast<Model::Action*>(model)->IsFinished()){
-      std::map<Model::ActionRef,std::wstring>::iterator iter=strings.find(dynamic_cast<Model::Action*>(model));
+    if (string!=NULL) {
+      if (dynamic_cast<Model::Action*>(model)!=NULL &&
+          dynamic_cast<Model::Action*>(model)->IsFinished()) {
+        std::map<Model::ActionRef,std::wstring>::iterator iter=strings.find(dynamic_cast<Model::Action*>(model));
 
-      if (iter!=strings.end()) {
-        string->ActionInsertString(iter->second);
+        if (iter!=strings.end()) {
+          string->ActionInsertString(iter->second);
+        }
       }
       else if (model==backAction) {
         string->ActionBackspace();
       }
     }
+
     Popup::Resync(model,msg);
   }
 
   InputHelperNumber::InputHelperNumber(Type type)
-   : type(type),
-     colonAction(new Model::Action())
+   : type(type)
   {
-    digitActions.resize(16);
-
-    for (size_t i=0; i<=15; i++) {
-      digitActions[i]=new Lum::Model::Action();
-    }
+    // no code
   }
 
   void InputHelperNumber::PreInit()
@@ -1720,7 +1720,8 @@ namespace Lum {
       array->Add(CreateTextButton(L"3",L"3"));
 
       array->Add(CreateTextButton(L"0",L"0"));
-      array->Add(CreateTextButton(Lum::Base::GetDecimalPointWString(),Lum::Base::GetDecimalPointWString()));
+      array->Add(CreateTextButton(Lum::Base::GetDecimalPointWString(),
+                                  Lum::Base::GetDecimalPointWString()));
       array->Add(CreateTextButton(L"<-",backAction));
     }
     else if (type==typeFloat) {
@@ -1741,7 +1742,8 @@ namespace Lum {
       array->Add(CreateTextButton(L"e",L"e"));
 
       array->Add(CreateTextButton(L"0",L"0"));
-      array->Add(CreateTextButton(Lum::Base::GetDecimalPointWString(),Lum::Base::GetDecimalPointWString()));
+      array->Add(CreateTextButton(Lum::Base::GetDecimalPointWString(),
+                                  Lum::Base::GetDecimalPointWString()));
       array->AddEmpty();
       array->Add(CreateTextButton(L"<-",backAction));
     }
